#' needs_layer
#' @description Checks if layer existing in geopackage
#' @param db character geopackage to check
#' @param layer character layer name
#' @return logical
#' @export
#' @importFrom sf st_layers

needs_layer <- function(db, layer) {

  try({  if(file.exists(db)) {
    layers <- st_layers(db)
    if(layer %in% layers$name)
      return(FALSE)
  }
  })

  TRUE
}

layer_exists <- function(db, layer) {
  if(file.exists(db)) {
    layers <- st_layers(db)
    if(layer %in% layers$name)
      return(TRUE)
  }
  FALSE
}

#' get RPU dependent variables
#' @description Will look for environment variables "RPU_CODE" and "HYDREG"
#' for `r` and `v` inputs. If r is provided, v will be set accordingly in the output.
#' @param r character RPU code.
#' @param v character VPU code
#' @return list with r and v set.
#' @export
#'
get_rpu_dependent_vars <- function(r = Sys.getenv("RPU_CODE"),
                                   v = Sys.getenv("HYDREG")) {
  if(nchar(r) == 3) rpu_code <- r

  if(nchar(v) > 1) vpu_code <- v

  if(exists("rpu_code") && !exists("vpu_code")) {
    vpu_code <- substr(rpu_code, 1, 2)

    if(rpu_code %in% c("10a", "10b", "10c", "10d")) {
      vpu_code <- "10L"
    }

    if(rpu_code %in% c("10e", "10f", "10g", "10h", "10i")) {
      vpu_code <- "10U"
    }

    if(rpu_code %in% c("03a", "03b")) {
      vpu_code <- "03N"
    }

    if(rpu_code %in% c("03c", "03d")) {
      vpu_code <- "03S"
    }

    if(rpu_code %in% c("03e", "03f")) {
      vpu_code <- "03W"
    }

    if(rpu_code == "03g") {
      vpu_code = "08"
    }
  }

  if(!exists("vpu_code")) vpu_code <- "01"

  if(!exists("rpu_code")) rpu_code <- "01a"

  return(list(r = rpu_code, v = vpu_code))
}

